declare namespace java {
    namespace awt {
        /**
         * This class represents a check box that can be included in a menu.
         * Selecting the check box in the menu changes its state from
         * "on" to "off" or from "off" to "on."
         * <p>
         * The following picture depicts a menu which contains an instance
         * of <code>CheckBoxMenuItem</code>:
         * <p>
         * <img src="doc-files/MenuBar-1.gif"
         * alt="Menu labeled Examples, containing items Basic, Simple, Check, and More Examples. The Check item is a CheckBoxMenuItem instance, in the off state."
         * style="float:center; margin: 7px 10px;">
         * <p>
         * The item labeled <code>Check</code> shows a check box menu item
         * in its "off" state.
         * <p>
         * When a check box menu item is selected, AWT sends an item event to
         * the item. Since the event is an instance of <code>ItemEvent</code>,
         * the <code>processEvent</code> method examines the event and passes
         * it along to <code>processItemEvent</code>. The latter method redirects
         * the event to any <code>ItemListener</code> objects that have
         * registered an interest in item events generated by this menu item.
         * @author Sami Shaio
         * @see java.awt.event.ItemEvent
         * @see java.awt.event.ItemListener
         * @since JDK1.0
         */
        // @ts-ignore
        class CheckboxMenuItem extends java.awt.MenuItem implements java.awt.ItemSelectable, javax.accessibility.Accessible {
            /**
             * Create a check box menu item with an empty label.
             * The item's state is initially set to "off."
             * @exception HeadlessException if GraphicsEnvironment.isHeadless()
             *  returns true
             * @see java.awt.GraphicsEnvironment#isHeadless
             * @since JDK1.1
             */
            // @ts-ignore
            constructor()
            /**
             * Create a check box menu item with the specified label.
             * The item's state is initially set to "off."
             * @param label   a string label for the check box menu item,
             *                 or <code>null</code> for an unlabeled menu item.
             * @exception HeadlessException if GraphicsEnvironment.isHeadless()
             *  returns true
             * @see java.awt.GraphicsEnvironment#isHeadless
             */
            // @ts-ignore
            constructor(label: java.lang.String | string)
            /**
             * Create a check box menu item with the specified label and state.
             * @param label   a string label for the check box menu item,
             *                      or <code>null</code> for an unlabeled menu item.
             * @param state   the initial state of the menu item, where
             *                      <code>true</code> indicates "on" and
             *                      <code>false</code> indicates "off."
             * @exception HeadlessException if GraphicsEnvironment.isHeadless()
             *  returns true
             * @see java.awt.GraphicsEnvironment#isHeadless
             * @since JDK1.1
             */
            // @ts-ignore
            constructor(label: java.lang.String | string, state: boolean)
            /**
             * Creates the peer of the checkbox item.  This peer allows us to
             * change the look of the checkbox item without changing its
             * functionality.
             * Most applications do not call this method directly.
             * @see java.awt.Toolkit#createCheckboxMenuItem(java.awt.CheckboxMenuItem)
             * @see java.awt.Component#getToolkit()
             */
            // @ts-ignore
            public addNotify(): void
            /**
             * Determines whether the state of this check box menu item
             * is "on" or "off."
             * @return the state of this check box menu item, where
             *                      <code>true</code> indicates "on" and
             *                      <code>false</code> indicates "off"
             * @see #setState
             */
            // @ts-ignore
            public getState(): boolean
            /**
             * Sets this check box menu item to the specified state.
             * The boolean value <code>true</code> indicates "on" while
             * <code>false</code> indicates "off."
             * <p>Note that this method should be primarily used to
             * initialize the state of the check box menu item.
             * Programmatically setting the state of the check box
             * menu item will <i>not</i> trigger
             * an <code>ItemEvent</code>.  The only way to trigger an
             * <code>ItemEvent</code> is by user interaction.
             * @param b   <code>true</code> if the check box
             *              menu item is on, otherwise <code>false</code>
             * @see #getState
             */
            // @ts-ignore
            public setState(b: boolean): void
            /**
             * Returns the an array (length 1) containing the checkbox menu item
             * label or null if the checkbox is not selected.
             * @see ItemSelectable
             */
            // @ts-ignore
            public getSelectedObjects(): any[]
            /**
             * Adds the specified item listener to receive item events from
             * this check box menu item.  Item events are sent in response to user
             * actions, but not in response to calls to setState().
             * If l is null, no exception is thrown and no action is performed.
             * <p>Refer to <a href="doc-files/AWTThreadIssues.html#ListenersThreads"
             * >AWT Threading Issues</a> for details on AWT's threading model.
             * @param l the item listener
             * @see #removeItemListener
             * @see #getItemListeners
             * @see #setState
             * @see java.awt.event.ItemEvent
             * @see java.awt.event.ItemListener
             * @since JDK1.1
             */
            // @ts-ignore
            public addItemListener(l: java.awt.event.ItemListener): void
            /**
             * Removes the specified item listener so that it no longer receives
             * item events from this check box menu item.
             * If l is null, no exception is thrown and no action is performed.
             * <p>Refer to <a href="doc-files/AWTThreadIssues.html#ListenersThreads"
             * >AWT Threading Issues</a> for details on AWT's threading model.
             * @param l the item listener
             * @see #addItemListener
             * @see #getItemListeners
             * @see java.awt.event.ItemEvent
             * @see java.awt.event.ItemListener
             * @since JDK1.1
             */
            // @ts-ignore
            public removeItemListener(l: java.awt.event.ItemListener): void
            /**
             * Returns an array of all the item listeners
             * registered on this checkbox menuitem.
             * @return all of this checkbox menuitem's <code>ItemListener</code>s
             *          or an empty array if no item
             *          listeners are currently registered
             * @see #addItemListener
             * @see #removeItemListener
             * @see java.awt.event.ItemEvent
             * @see java.awt.event.ItemListener
             * @since 1.4
             */
            // @ts-ignore
            public getItemListeners(): java.awt.event.ItemListener[]
            /**
             * Returns an array of all the objects currently registered
             * as <code><em>Foo</em>Listener</code>s
             * upon this <code>CheckboxMenuItem</code>.
             * <code><em>Foo</em>Listener</code>s are registered using the
             * <code>add<em>Foo</em>Listener</code> method.
             * <p>
             * You can specify the <code>listenerType</code> argument
             * with a class literal, such as
             * <code><em>Foo</em>Listener.class</code>.
             * For example, you can query a
             * <code>CheckboxMenuItem</code> <code>c</code>
             * for its item listeners with the following code:
             * <pre>ItemListener[] ils = (ItemListener[])(c.getListeners(ItemListener.class));</pre>
             * If no such listeners exist, this method returns an empty array.
             * @param listenerType the type of listeners requested; this parameter
             *           should specify an interface that descends from
             *           <code>java.util.EventListener</code>
             * @return an array of all objects registered as
             *           <code><em>Foo</em>Listener</code>s on this checkbox menuitem,
             *           or an empty array if no such
             *           listeners have been added
             * @exception ClassCastException if <code>listenerType</code>
             *           doesn't specify a class or interface that implements
             *           <code>java.util.EventListener</code>
             * @see #getItemListeners
             * @since 1.3
             */
            // @ts-ignore
            public getListeners<T extends java.util.EventListener>(listenerType: java.lang.Class<T>): T
            /**
             * Processes events on this check box menu item.
             * If the event is an instance of <code>ItemEvent</code>,
             * this method invokes the <code>processItemEvent</code> method.
             * If the event is not an item event,
             * it invokes <code>processEvent</code> on the superclass.
             * <p>
             * Check box menu items currently support only item events.
             * <p>Note that if the event parameter is <code>null</code>
             * the behavior is unspecified and may result in an
             * exception.
             * @param e the event
             * @see java.awt.event.ItemEvent
             * @see #processItemEvent
             * @since JDK1.1
             */
            // @ts-ignore
            processEvent(e: java.awt.AWTEvent): void
            /**
             * Processes item events occurring on this check box menu item by
             * dispatching them to any registered <code>ItemListener</code> objects.
             * <p>
             * This method is not called unless item events are
             * enabled for this menu item. Item events are enabled
             * when one of the following occurs:
             * <ul>
             * <li>An <code>ItemListener</code> object is registered
             * via <code>addItemListener</code>.
             * <li>Item events are enabled via <code>enableEvents</code>.
             * </ul>
             * <p>Note that if the event parameter is <code>null</code>
             * the behavior is unspecified and may result in an
             * exception.
             * @param e the item event
             * @see java.awt.event.ItemEvent
             * @see java.awt.event.ItemListener
             * @see #addItemListener
             * @see java.awt.MenuItem#enableEvents
             * @since JDK1.1
             */
            // @ts-ignore
            processItemEvent(e: java.awt.event.ItemEvent): void
            /**
             * Returns a string representing the state of this
             * <code>CheckBoxMenuItem</code>. This
             * method is intended to be used only for debugging purposes, and the
             * content and format of the returned string may vary between
             * implementations. The returned string may be empty but may not be
             * <code>null</code>.
             * @return the parameter string of this check box menu item
             */
            // @ts-ignore
            public paramString(): string
            /**
             * Gets the AccessibleContext associated with this CheckboxMenuItem.
             * For checkbox menu items, the AccessibleContext takes the
             * form of an AccessibleAWTCheckboxMenuItem.
             * A new AccessibleAWTCheckboxMenuItem is created if necessary.
             * @return an AccessibleAWTCheckboxMenuItem that serves as the
             *          AccessibleContext of this CheckboxMenuItem
             * @since 1.3
             */
            // @ts-ignore
            public getAccessibleContext(): javax.accessibility.AccessibleContext
        }
    }
}
