declare namespace java {
    namespace io {
        /**
         * Convenience class for writing character files.  The constructors of this
         * class assume that the default character encoding and the default byte-buffer
         * size are acceptable.  To specify these values yourself, construct an
         * OutputStreamWriter on a FileOutputStream.
         * <p>Whether or not a file is available or may be created depends upon the
         * underlying platform.  Some platforms, in particular, allow a file to be
         * opened for writing by only one <tt>FileWriter</tt> (or other file-writing
         * object) at a time.  In such situations the constructors in this class
         * will fail if the file involved is already open.
         * <p><code>FileWriter</code> is meant for writing streams of characters.
         * For writing streams of raw bytes, consider using a
         * <code>FileOutputStream</code>.
         * @see OutputStreamWriter
         * @see FileOutputStream
         * @author Mark Reinhold
         * @since JDK1.1
         */
        // @ts-ignore
        class FileWriter extends java.io.OutputStreamWriter {
            /**
             * Constructs a FileWriter object given a file name.
             * @param fileName  String The system-dependent filename.
             * @throws IOException  if the named file exists but is a directory rather
             *                   than a regular file, does not exist but cannot be
             *                   created, or cannot be opened for any other reason
             */
            // @ts-ignore
            constructor(fileName: java.lang.String | string)
            /**
             * Constructs a FileWriter object given a file name with a boolean
             * indicating whether or not to append the data written.
             * @param fileName  String The system-dependent filename.
             * @param append    boolean if <code>true</code>, then data will be written
             *                   to the end of the file rather than the beginning.
             * @throws IOException  if the named file exists but is a directory rather
             *                   than a regular file, does not exist but cannot be
             *                   created, or cannot be opened for any other reason
             */
            // @ts-ignore
            constructor(fileName: java.lang.String | string, append: boolean)
            /**
             * Constructs a FileWriter object given a File object.
             * @param file  a File object to write to.
             * @throws IOException  if the file exists but is a directory rather than
             *                   a regular file, does not exist but cannot be created,
             *                   or cannot be opened for any other reason
             */
            // @ts-ignore
            constructor(file: java.io.File)
            /**
             * Constructs a FileWriter object given a File object. If the second
             * argument is <code>true</code>, then bytes will be written to the end
             * of the file rather than the beginning.
             * @param file  a File object to write to
             * @param append    if <code>true</code>, then bytes will be written
             *                       to the end of the file rather than the beginning
             * @throws IOException  if the file exists but is a directory rather than
             *                   a regular file, does not exist but cannot be created,
             *                   or cannot be opened for any other reason
             * @since 1.4
             */
            // @ts-ignore
            constructor(file: java.io.File, append: boolean)
            /**
             * Constructs a FileWriter object associated with a file descriptor.
             * @param fd  FileDescriptor object to write to.
             */
            // @ts-ignore
            constructor(fd: java.io.FileDescriptor)
        }
    }
}
